@@ -540,6 +540,13 @@ Read raw WebSocket data, only used by servers.
 
 Raw WebSocket data to write, only used by servers.
 
+=head1 DEBUGGING
+
+You can set the C<MOJO_WEBSOCKET_DEBUG> environment variable to get some
+advanced diagnostics information printed to C<STDERR>.
+
+  MOJO_WEBSOCKET_DEBUG=1
+
 =head1 SEE ALSO
 
 L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
